==> vue-cli-plugin-auth-jwt-0.1.6.tgz: package/src/lib/auth-vue-store-manager.ts <==
import { VueConstructor } from 'vue';
import { AuthUser, VueAuthOptions } from '../interfaces/VueAuthOptions';
import { VueAuthStore } from '../interfaces/VueAuthStore';
import StoreCookie from './store/store-cookie';
import StoreLocalStorage from './store/store-local-storage';
import StoreSessionStorage from './store/store-session-storage';

export type StoreType = StoreCookie | StoreSessionStorage | StoreLocalStorage;

export default class AuthStoreManager implements VueAuthStore {
  private stores: StoreType[];

  constructor(private Vue: VueConstructor, private options: VueAuthOptions) {
    this.setStores();
  }

  getStores() {
    return Object.assign([], this.stores);
  }

  setStores() {
    this.stores = [];
    Object.assign([], this.options.tokenStore)
      .forEach((store) => {
        let result;
        switch (store) {
          case 'cookie':
            result = new StoreCookie(this.Vue, this.options);
            break;
          case 'sessionStorage':
            try {
              result = new StoreSessionStorage(this.Vue, this.options);
            } catch (_) {
              result = null;
            }
            break;
          default:
            try {
              result = new StoreLocalStorage(this.Vue, this.options);
            } catch (_) {
              result = null;
            }
        }
        if (result) {
          this.stores.push(result);
        }
      });
  }

  getRoles(): string[] {
    return this.getStores()
      .map((store) => store.getRoles())
      .filter((roles) => roles && roles.length)[0];
  }

  getToken(): string {
    return this.getStores()
      .map((store) => store.getToken())
      .filter((token) => !!token)[0];
  }

  getUser(): AuthUser {
    return this.getStores()
      .map((store) => store.getUser())
      .filter((user) => !!user)[0] || {};
  }

  setToken(token: string): void {
    this.getStores()
      .forEach((store) => {
        store.setToken(token);
      });
  }

  setUser(user: AuthUser): void {
    this.getStores()
      .forEach((store) => {
        store.setUser(user);
      });
  }

  resetAll(): void {
    this.setUser(null);
    this.setToken(null);
  }

  checkRole(role?: string | string[]): boolean {
    if (role) {
      const roles = this.getRoles();
      if (!roles) {
        return false;
      }
      if (Array.isArray(role)) {
        return roles.some((authrole) => role.includes(authrole));
      } else {
        return roles.includes(role);
      }
    } else {
      return !!this.getToken();
    }
  }
}

==> vue-cli-plugin-auth-jwt-0.1.11.tgz: package/src/lib/auth-vue-store-manager.ts <==
import { VueConstructor } from 'vue';
import { AuthUser, VueAuthOptions } from '../interfaces/VueAuthOptions';
import { VueAuthStore } from '../interfaces/VueAuthStore';
import StoreCookie from './store/store-cookie';
import StoreLocalStorage from './store/store-local-storage';
import StoreSessionStorage from './store/store-session-storage';

export type StoreType = StoreCookie | StoreSessionStorage | StoreLocalStorage;

export default class AuthStoreManager implements VueAuthStore {
  private stores: StoreType[];

  constructor(private Vue: VueConstructor, private options: VueAuthOptions) {
    this.setStores();
  }

  public getStores() {
    return Object.assign([], this.stores);
  }

  public setStores() {
    this.stores = [];
    Object.assign([], this.options.tokenStore)
      .forEach((store) => {
        let result;
        switch (store) {
          case 'cookie':
            result = new StoreCookie(this.Vue, this.options);
            break;
          case 'sessionStorage':
            try {
              result = new StoreSessionStorage(this.Vue, this.options);
            } catch (_) {
              result = null;
            }
            break;
          default:
            try {
              result = new StoreLocalStorage(this.Vue, this.options);
            } catch (_) {
              result = null;
            }
        }
        if (result) {
          this.stores.push(result);
        }
      });
  }

  public getRoles(): string[] {
    return this.getStores()
      .map((store) => store.getRoles())
      .filter((roles) => roles && roles.length)[0];
  }

  public getToken(): string {
    return this.getStores()
      .map((store) => store.getToken())
      .filter((token) => !!token)[0];
  }

  public getUser(): AuthUser {
    return this.getStores()
      .map((store) => store.getUser())
      .filter((user) => !!user)[0] || {};
  }

  public setToken(token: string): void {
    this.getStores()
      .forEach((store) => {
        store.setToken(token);
      });
  }

  public setUser(user: AuthUser): void {
    this.getStores()
      .forEach((store) => {
        store.setUser(user);
      });
  }

  public resetAll(): void {
    this.setUser(null);
    this.setToken(null);
  }

  public checkRole(role?: string | string[]): boolean {
    if (role) {
      const roles = this.getRoles();
      if (!roles) {
        return false;
      }
      if (Array.isArray(role)) {
        return roles.some((authrole) => role.includes(authrole));
      } else {
        return roles.includes(role);
      }
    } else {
      return !!this.getToken();
    }
  }
}
